# Generated by Django 5.0.8 on 2024-08-26 12:39

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
    ]

    operations = [
        migrations.CreateModel(
            name="Cycle",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("cycle", models.CharField(max_length=100, unique=True)),
                ("year_code", models.CharField(blank=True, max_length=10, null=True)),
                (
                    "base_url",
                    models.URLField(default="https://wwwn.cdc.gov/Nchs/Nhanes"),
                ),
                (
                    "dataset_url_pattern",
                    models.CharField(default="%s/%s/%s", max_length=255),
                ),
            ],
            options={
                "verbose_name_plural": "01-Cycles",
                "ordering": ["cycle"],
            },
        ),
        migrations.CreateModel(
            name="Dataset",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("dataset", models.CharField(max_length=100)),
                ("description", models.TextField(blank=True, null=True)),
            ],
            options={
                "verbose_name_plural": "03-Dataset",
            },
        ),
        migrations.CreateModel(
            name="Group",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("group", models.CharField(max_length=100, unique=True)),
                ("description", models.TextField(blank=True, null=True)),
            ],
            options={
                "verbose_name_plural": "02-Group",
            },
        ),
        migrations.CreateModel(
            name="QueryColumns",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("column_name", models.CharField(max_length=100, unique=True)),
                (
                    "internal_data_key",
                    models.CharField(blank=True, max_length=100, null=True),
                ),
                ("column_description", models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name="Tag",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tag", models.CharField(max_length=50, unique=True)),
                (
                    "description",
                    models.CharField(blank=True, max_length=255, null=True),
                ),
            ],
            options={
                "verbose_name": "Tag",
                "verbose_name_plural": "Tags",
            },
        ),
        migrations.CreateModel(
            name="Version",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("version", models.CharField(max_length=50, unique=True)),
                (
                    "description",
                    models.CharField(blank=True, max_length=255, null=True),
                ),
            ],
        ),
        migrations.CreateModel(
            name="WorkProcessMasterData",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "component_type",
                    models.CharField(
                        choices=[
                            ("SystemConfig", "System Config"),
                            ("Cycle", "Cycle"),
                            ("Group", "Group"),
                            ("Dataset", "Dataset"),
                            ("Variable", "Variable"),
                            ("DatasetCycle", "Dataset Cycle"),
                            ("VariableCycle", "Variable Cycle"),
                            ("Rule", "Rule"),
                            ("QueryColumns", "Query Columns"),
                        ],
                        max_length=20,
                        unique=True,
                    ),
                ),
                ("last_synced_at", models.DateTimeField(auto_now_add=True)),
                (
                    "source_file_version",
                    models.CharField(blank=True, default="", max_length=500, null=True),
                ),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("pending", "Pending"),
                            ("complete", "Complete"),
                            ("error", "Error"),
                            ("delete", "Delete"),
                            ("standby", "Stand By"),
                            ("no_file", "No File"),
                        ],
                        default="pending",
                        max_length=20,
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "Work Process Master Data",
            },
        ),
        migrations.CreateModel(
            name="DatasetCycle",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("metadata_url", models.URLField(blank=True, null=True)),
                ("description", models.JSONField(blank=True, null=True)),
                ("has_special_year_code", models.BooleanField(default=False)),
                (
                    "special_year_code",
                    models.CharField(blank=True, max_length=10, null=True),
                ),
                ("has_dataset", models.BooleanField(default=False)),
                (
                    "cycle",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.cycle"
                    ),
                ),
                (
                    "dataset",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.dataset"
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "06-Dataset by Cycle",
                "unique_together": {("dataset", "cycle")},
            },
        ),
        migrations.AddField(
            model_name="dataset",
            name="group",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to="nhanes.group"
            ),
        ),
        migrations.CreateModel(
            name="Logs",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("object_id", models.PositiveIntegerField(blank=True, null=True)),
                ("system_version", models.CharField(default="0.0.4", max_length=15)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("e", "Error"),
                            ("i", "Information"),
                            ("w", "Warning"),
                            ("s", "Success"),
                        ],
                        default="s",
                        max_length=1,
                    ),
                ),
                ("description", models.TextField(blank=True, default=None, null=True)),
                (
                    "content_type",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="contenttypes.contenttype",
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "Logs",
            },
        ),
        migrations.CreateModel(
            name="QueryStructure",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("structure_name", models.CharField(max_length=100)),
                ("no_conflict", models.BooleanField(default=False)),
                ("no_multi_index", models.BooleanField(default=False)),
                (
                    "columns",
                    models.ManyToManyField(
                        related_name="query_columns", to="nhanes.querycolumns"
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "08-Query Structure",
            },
        ),
        migrations.CreateModel(
            name="QueryFilter",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "filter_name",
                    models.CharField(
                        choices=[
                            ("variable__variable", "Variable Code"),
                            ("variable__description", "Variable Name"),
                            ("cycle__cycle", "Cycle"),
                            ("dataset__group__group", "Group"),
                            ("dataset__dataset", "Dataset Code"),
                            ("dataset__description", "Dataset Name"),
                        ],
                        default="variable",
                        max_length=30,
                    ),
                ),
                (
                    "operator",
                    models.CharField(
                        choices=[
                            ("eq", "Equal"),
                            ("ne", "Not Equal"),
                            ("lt", "Less Than"),
                            ("lte", "Less Than or Equal"),
                            ("gt", "Greater Than"),
                            ("gte", "Greater Than or Equal"),
                            ("contains", "Contains"),
                            ("icontains", "Contains (Case-Insensitive)"),
                            ("exact", "Exact"),
                            ("iexact", "Exact (Case-Insensitive)"),
                            ("in", "In"),
                            ("startswith", "Starts With"),
                            ("istartswith", "Starts With (Case-Insensitive)"),
                            ("endswith", "Ends With"),
                            ("iendswith", "Ends With (Case-Insensitive)"),
                            ("isnull", "Search For Null Values"),
                            ("search", "Search"),
                            ("regex", "Use Regular Expression"),
                            ("iregex", "Use Regular Expression (Case-Insensitive)"),
                            ("file", "Path to csv file with each value in a line"),
                        ],
                        default="eq",
                        max_length=20,
                    ),
                ),
                ("value", models.CharField(max_length=255)),
                (
                    "query_structure",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="filters",
                        to="nhanes.querystructure",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="Rule",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("rule", models.CharField(max_length=255, unique=True)),
                ("version", models.CharField(max_length=20)),
                ("description", models.TextField(blank=True, null=True)),
                ("is_active", models.BooleanField(default=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("repo_url", models.URLField(blank=True, null=True)),
            ],
            options={
                "verbose_name_plural": "Rules",
                "unique_together": {("rule", "version")},
            },
        ),
        migrations.CreateModel(
            name="Variable",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("variable", models.CharField(max_length=100, unique=True)),
                ("description", models.TextField(blank=True, null=True)),
                ("is_active", models.BooleanField(default=True)),
                (
                    "type",
                    models.CharField(
                        choices=[
                            ("bin", "Binary"),
                            ("cat", "Category"),
                            ("num", "Numeric"),
                            ("tex", "Text"),
                            ("oth", "Other"),
                        ],
                        default="oth",
                        max_length=20,
                    ),
                ),
                (
                    "tags",
                    models.ManyToManyField(
                        blank=True, related_name="features", to="nhanes.tag"
                    ),
                ),
            ],
            options={
                "verbose_name": "Variable",
                "verbose_name_plural": "Variable",
            },
        ),
        migrations.CreateModel(
            name="RuleVariable",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "type",
                    models.CharField(
                        choices=[("i", "in"), ("o", "out")], default="i", max_length=1
                    ),
                ),
                (
                    "dataset",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.dataset"
                    ),
                ),
                (
                    "rule",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.rule"
                    ),
                ),
                (
                    "variable",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="nhanes.variable",
                    ),
                ),
                (
                    "version",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.version"
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "Rule Variables",
            },
        ),
        migrations.CreateModel(
            name="WorkProcessRule",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced_at", models.DateTimeField(auto_now_add=True)),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("pending", "Pending"),
                            ("complete", "Complete"),
                            ("error", "Error"),
                            ("delete", "Delete"),
                            ("standby", "Stand By"),
                        ],
                        default="pending",
                        max_length=20,
                    ),
                ),
                ("execution_logs", models.TextField(blank=True, null=True)),
                ("execution_time", models.DurationField(blank=True, null=True)),
                ("attempt_count", models.PositiveIntegerField(default=0)),
                (
                    "rule",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.rule"
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "Work Process Rule",
            },
        ),
        migrations.AlterUniqueTogether(
            name="dataset",
            unique_together={("dataset", "group")},
        ),
        migrations.CreateModel(
            name="VariableCycle",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("variable_name", models.CharField(max_length=100)),
                ("sas_label", models.CharField(max_length=100)),
                ("english_text", models.TextField()),
                ("target", models.CharField(max_length=100)),
                ("type", models.CharField(max_length=100)),
                ("value_table", models.JSONField()),
                (
                    "cycle",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.cycle"
                    ),
                ),
                (
                    "dataset",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.dataset"
                    ),
                ),
                (
                    "variable",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="nhanes.variable",
                    ),
                ),
                (
                    "version",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.version"
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "05-Variable by Cycle",
                "indexes": [
                    models.Index(
                        fields=["variable", "cycle"],
                        name="nhanes_vari_variabl_59ffa1_idx",
                    )
                ],
                "unique_together": {("variable", "cycle")},
            },
        ),
        migrations.CreateModel(
            name="Data",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("sample", models.IntegerField()),
                ("sequence", models.IntegerField(default=0)),
                ("value", models.CharField(max_length=255)),
                (
                    "cycle",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.cycle"
                    ),
                ),
                (
                    "dataset",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.dataset"
                    ),
                ),
                (
                    "rule_id",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="nhanes.rule",
                    ),
                ),
                (
                    "variable",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="nhanes.variable",
                    ),
                ),
                (
                    "version",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.version"
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "Data Records",
                "indexes": [
                    models.Index(
                        fields=["sample", "variable", "cycle", "dataset", "version"],
                        name="nhanes_data_sample_00429b_idx",
                    )
                ],
            },
        ),
        migrations.CreateModel(
            name="WorkProcessNhanes",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("is_download", models.BooleanField(default=False)),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("pending", "Pending"),
                            ("complete", "Complete"),
                            ("error", "Error"),
                            ("delete", "Delete"),
                            ("standby", "Stand By"),
                            ("no_file", "No File"),
                        ],
                        default="pending",
                        max_length=20,
                    ),
                ),
                (
                    "last_synced_at",
                    models.DateTimeField(auto_now=True, verbose_name="Last Update"),
                ),
                (
                    "source_file_version",
                    models.CharField(blank=True, default="", max_length=500, null=True),
                ),
                ("source_file_size", models.BigIntegerField(default=0)),
                ("system_version", models.CharField(default="0.0.4", max_length=15)),
                ("time_download", models.IntegerField(default=0)),
                ("time", models.IntegerField(default=0)),
                ("records", models.IntegerField(default=0)),
                ("n_samples", models.IntegerField(default=0)),
                ("n_variables", models.IntegerField(default=0)),
                (
                    "cycle",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.cycle"
                    ),
                ),
                (
                    "dataset",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="nhanes.dataset"
                    ),
                ),
                (
                    "datasetcycle",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="nhanes.datasetcycle",
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "Work Process",
                "unique_together": {("dataset", "cycle")},
            },
        ),
    ]
